@@ -4,7 +4,8 @@
 // See file LICENSE for details and terms of copying.
 
 #import <simtoolsgui/GUISwarm.h>
-#import <analysis.h>
+#import <analysis.h> // EZGraph
+#import <space.h> // Value2dDisplay, Object2dDisplay
 #import "ModelSwarm.h"
 
 // The observer swarm contains all the objects used to instrument a model
@@ -19,11 +20,11 @@
 
   id <Colormap> colormap;			  // colours
   id <ZoomRaster> worldRaster;			  // window on world
-  Value2dDisplay *sugarDisplay;			  // sugar displayer
-  Object2dDisplay *agentDisplay;		  // agent displayer
-  EZGraph *populationGraph;			  // population graph
-  EZGraph *attributeGraph;			  // agent attributes graph
-  EZBin *wealthHistogram;			  // histogram of wealth
+  id <Value2dDisplay> sugarDisplay;		  // sugar displayer
+  id <Object2dDisplay> agentDisplay;		  // agent displayer
+  id <EZGraph> populationGraph;			  // population graph
+  id <EZGraph> attributeGraph;			  // agent attributes graph
+  id <EZBin> wealthHistogram;			  // histogram of wealth
 
   id displayActions;				  // schedule objects
   id displaySchedule;
@@ -35,3 +36,4 @@
 - activateIn: swarmContext;
 
 @end
+
