@@ -7,7 +7,7 @@
 // object to shuffle Swarm List list with num elts, in place
 // from Knuth vol 2
 
-#import <objectbase.h>
+#import <objectbase/SwarmObject.h>
 #import <random.h>
 
 @interface Shuffler: SwarmObject
